import pathlib

import click.testing

from dsw.tdk import main


def test_creates_dot_env(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['https://example.com', 'mySecretKey']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)

        result = runner.invoke(main, args=['dot-env', root_dir.as_posix()], input='\n'.join(inputs))
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert '.env' in paths


def test_dot_env_contents(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['https://example.com', 'mySecretKey']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        dot_env = root_dir / '.env'

        result = runner.invoke(main, args=['dot-env', root_dir.as_posix()], input='\n'.join(inputs))
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert '.env' in paths
        contents = dot_env.read_text(encoding='utf-8')
        assert 'DSW_API_URL=https://example.com' in contents
        assert 'DSW_API_KEY=mySecretKey' in contents


def test_dot_env_no_force(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['https://example.com', 'mySecretKey']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        dot_env = root_dir / '.env'
        dot_env.write_text('test')

        result = runner.invoke(main, args=['dot-env', root_dir.as_posix()], input='\n'.join(inputs))
        assert result.exception
        assert result.exit_code == 1

        contents = dot_env.read_text(encoding='utf-8')
        assert 'test' in contents


def test_dot_env_overwrites(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['https://example.com', 'mySecretKey']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        dot_env = root_dir / '.env'
        dot_env.write_text('test')

        result = runner.invoke(main, args=['dot-env', root_dir.as_posix(), '--force'], input='\n'.join(inputs))
        print(result.stdout)
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert '.env' in paths
        contents = dot_env.read_text(encoding='utf-8')
        assert 'DSW_API_URL=https://example.com' in contents
        assert 'DSW_API_KEY=mySecretKey' in contents



import pathlib

import click.testing

from dsw.tdk import main


def test_new_no_dir(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['Test template', 'dsw', 'test-template', '0.1.0', 'some description', 'CC0',
              'y', 'HTML', 'html', 'text/html', 'src/template.html.j2', 'n']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        result = runner.invoke(main, args=['new'], input='\n'.join(inputs))
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert 'dsw_test-template_0.1.0/template.json' in paths
        assert 'dsw_test-template_0.1.0/README.md' in paths
        assert 'dsw_test-template_0.1.0/src' in paths
        assert 'dsw_test-template_0.1.0/src/template.html.j2' in paths


def test_new_dir(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['Test template', 'dsw', 'test-template', '0.1.0', 'some description', 'CC0',
              'y', 'HTML', 'html', 'text/html', 'src/template.html.j2', 'n']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        result = runner.invoke(main, args=['new', 'my-template'], input='\n'.join(inputs))
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert 'my-template/template.json' in paths
        assert 'my-template/README.md' in paths
        assert 'my-template/src' in paths
        assert 'my-template/src/template.html.j2' in paths


def test_new_without_force(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['Test template', 'dsw', 'test-template', '0.1.0', 'some description', 'CC0',
              'y', 'HTML', 'html', 'text/html', 'src/template.html.j2', 'n']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        template_json = root_dir / 'template.json'
        template_json.write_text('foo', encoding='utf-8')

        result = runner.invoke(main, args=['new', '.'], input='\n'.join(inputs))
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert 'template.json' in paths
        assert 'README.md' in paths
        assert 'src' in paths
        assert 'src/template.html.j2' in paths
        assert template_json.read_text(encoding='utf-8') == 'foo'


def test_new_with_force(tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    inputs = ['Test template', 'dsw', 'test-template', '0.1.0', 'some description', 'CC0',
              'y', 'HTML', 'html', 'text/html', 'src/template.html.j2', 'n']
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        template_json = root_dir / 'template.json'
        template_json.write_text('foo', encoding='utf-8')

        result = runner.invoke(main, args=['new', '--force', '.'], input='\n'.join(inputs))
        assert not result.exception
        assert result.exit_code == 0
        paths = frozenset(map(lambda x: str(x.relative_to(isolated_dir).as_posix()), tmp_path.rglob('*')))
        assert 'template.json' in paths
        assert 'README.md' in paths
        assert 'src' in paths
        assert 'src/template.html.j2' in paths
        assert template_json.read_text(encoding='utf-8') != 'foo'



import pathlib

import click.testing
import pytest

from dsw.tdk import main


@pytest.mark.vcr
def test_put_ok(fixtures_path: pathlib.Path, dsw_env: dict):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    result = runner.invoke(main, args=['put', template_path.as_posix()], env=dsw_env)
    print(result.stdout)
    assert result.exit_code == 0


@pytest.mark.vcr
def test_put_faulty(fixtures_path: pathlib.Path, dsw_env: dict):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_faulty01'
    result = runner.invoke(main, args=['put', template_path.as_posix()], env=dsw_env)
    assert result.exit_code == 1


@pytest.mark.vcr
def test_put_published(fixtures_path: pathlib.Path, dsw_env: dict):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example02'
    result = runner.invoke(main, args=['put', template_path.as_posix()], env=dsw_env)
    assert result.exit_code == 1


@pytest.mark.vcr
def test_put_bad_token(fixtures_path: pathlib.Path, dsw_api_url: str):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    env_vars = {
        'DSW_API_URL': dsw_api_url,
        'DSW_API_KEY': 'foo',
    }
    result = runner.invoke(main, args=['put', template_path.as_posix()], env=env_vars)
    assert result.exit_code == 1


@pytest.mark.vcr
def test_put_bad_url(fixtures_path: pathlib.Path, dsw_api_key: str):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    env_vars = {
        'DSW_API_URL': 'http://localhost:33333',
        'DSW_API_KEY': dsw_api_key,
    }
    result = runner.invoke(main, args=['put', template_path.as_posix()], env=env_vars)
    assert result.exit_code == 1



import pathlib
import pathspec  # type: ignore
import re

APP = 'dsw-tdk'
VERSION = '4.0.0'
METAMODEL_VERSION = 11

REGEX_SEMVER = re.compile(r'^[0-9]+\.[0-9]+\.[0-9]+$')
REGEX_ORGANIZATION_ID = re.compile(r'^(?![.])(?!.*[.]$)[a-zA-Z0-9.]+$')
REGEX_TEMPLATE_ID = re.compile(r'^(?![-])(?!.*[-]$)[a-zA-Z0-9-]+$')
REGEX_KM_ID = REGEX_TEMPLATE_ID
REGEX_MIME_TYPE = re.compile(r'^(?![-])(?!.*[-]$)[-\w.]+/[-\w.]+$')

DEFAULT_LIST_FORMAT = '{template.id:<50} {template.name:<30}'
DEFAULT_ENCODING = 'utf-8'
DEFAULT_README = pathlib.Path('README.md')

TEMPLATE_FILE = 'template.json'
PATHSPEC_FACTORY = pathspec.patterns.GitWildMatchPattern



# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.0.0~1d16f01',
    built_at='2023-11-13 15:15:25Z',
    sha='1d16f0176b98178946bb47d9f95e0f09c97b371a',
    branch='HEAD',
    tag='v4.0.0',
)
